"""
    2D mesh fitting and interpolation.
    
    Maps quantity data over a 2D mesh. It calculates a smooth gradation of 
    data over the mesh, and allows data to be sampled at any given point.
"""

from numpy._pytesttester import PytestTester
test = PytestTester(__name__)
del PytestTester





